Crate minigrepr

Crate minigrepr 

#minigrepr

minigrepr is a collection of search functions for searching a given query in a file

Structs

Config

Functions

run
search
Case sensitive search of query in the given file contents
search_case_insenstive
Case insensitive search of query in the given file contents