#minigrepr
minigrepr is a collection of search functions for searching a given query in a file
Structs
Functions
- run
- search
- Case sensitive search of query in the given file contents
- search_
case_ insenstive - Case insensitive search of query in the given file contents